import React from "react";
import { Controller, useFormContext } from "react-hook-form";
import { dateShowConverter } from "./utils/dateShowConverter";
import { DBDateFormat, dbDateToVisual } from "./utils/dBDateToVisual";
import { datedispNewFormat } from "./utils/dateConverterNew";
const transferAsIDate = {
    output: (value) => {
        return { display: value, database: value };
    },
    outputOnBlur: (value) => {
        return datedispNewFormat(value);
    },
    input: (value) => {
        return value.dispDate;
    }
};
const transferAsString = {
    output: (value) => {
        if (!DBDateFormat.test(value))
            return value;
        else
            return dateShowConverter(value).dataDate;
    },
    outputOnBlur: (value) => {
        return dateShowConverter(value).dataDate;
    },
    input: (value) => {
        return dbDateToVisual(value);
    }
};
export const DateInput = ({ placeHolder, name, maxDate, minDate, defaultValue, format = 'DB' }) => {
    const formContext = useFormContext();
    const transferMethods = format === 'DB' ? transferAsString : transferAsIDate;
    return (React.createElement(React.Fragment, null,
        placeHolder,
        React.createElement(Controller, { name: name, control: formContext.control, rules: {
                max: maxDate,
                min: minDate
            }, defaultValue: defaultValue, render: ({ field }) => (React.createElement("input", Object.assign({ type: "text" }, field, { value: field.value ? transferMethods.input(field.value) : "", onChange: e => {
                    field.onChange(transferMethods.output(e.target.value));
                }, onBlur: e => field.onChange(transferMethods.outputOnBlur(e.target.value)) }))) })));
};
//# sourceMappingURL=DateInput.js.map